@@ -14,7 +14,7 @@
  * You should have received a copy of the GNU General Public License
  * along with YAD. If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2008-2022, Victor Ananjevsky <victor@sanana.kiev.ua>
+ * Copyright (C) 2008-2023, Victor Ananjevsky <victor@sanana.kiev.ua>
  */
 
 #include <sys/types.h>
@@ -350,16 +350,24 @@ create_layout (GtkWidget *dlg)
 static void
 realize_cb (GtkWidget *dlg, gpointer d)
 {
-  gint cw, ch;
-  /* get current window size for gtk_window_resize */
-  gtk_window_get_size (GTK_WINDOW (dlg), &cw, &ch);
-  if (options.data.width == -1)
-    options.data.width = cw;
-  if (options.data.height == -1)
-    options.data.height = ch;
+  GdkGravity gravity = GDK_GRAVITY_NORTH_WEST;
 
-  gtk_window_resize (GTK_WINDOW (dlg), options.data.width, options.data.height);
-  gtk_window_set_resizable (GTK_WINDOW (dlg), !options.data.fixed);
+  if (options.data.fixed)
+    {
+      gtk_widget_set_size_request (dlg, options.data.width, options.data.height);
+      gtk_window_set_resizable (GTK_WINDOW (dlg), !options.data.fixed);
+    }
+  else
+    {
+      gint cw, ch;
+      /* get current window size for gtk_window_resize */
+      gtk_window_get_size (GTK_WINDOW (dlg), &cw, &ch);
+      if (options.data.width == -1)
+        options.data.width = cw;
+      if (options.data.height == -1)
+        options.data.height = ch;
+      gtk_window_resize (GTK_WINDOW (dlg), options.data.width, options.data.height);
+    }
 
   if (options.data.use_posx || options.data.use_posy)
     {
@@ -371,10 +379,19 @@ realize_cb (GtkWidget *dlg, gpointer d)
         gtk_window_get_position (GTK_WINDOW (dlg), &options.data.posx, NULL);
       if (!options.data.use_posy)
         gtk_window_get_position (GTK_WINDOW (dlg), NULL, &options.data.posy);
-      if (options.data.posx < 0)
-        options.data.posx = sw - ww + options.data.posx;
-      if (options.data.posy < 0)
-        options.data.posy = sh - wh + options.data.posy;
+      if (options.data.negx)
+        {
+          options.data.posx = sw - ww + options.data.posx;
+          gravity = GDK_GRAVITY_NORTH_EAST;
+        }
+      if (options.data.negy)
+        {
+          options.data.posy = sh - wh + options.data.posy;
+          gravity = GDK_GRAVITY_SOUTH_WEST;
+        }
+      if (options.data.negx && options.data.negy)
+        gravity = GDK_GRAVITY_SOUTH_EAST;
+      gtk_window_set_gravity (GTK_WINDOW (dlg), gravity);
       gtk_window_move (GTK_WINDOW (dlg), options.data.posx, options.data.posy);
     }
 }
